gltforge_export_free

Function gltforge_export_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn gltforge_export_free(ctx: *mut ExportContext)
Free an export context without writing any files.

Safety

ctx must be a valid pointer returned by gltforge_export_begin that has not yet been consumed by gltforge_export_finish.